@@ -486,7 +486,7 @@ gdk_imlib_crop_image(GdkImlibImage * im, gint x, gint y, gint w, gint h)
 
   w3 = im->rgb_width * 3;
   w4 = (im->rgb_width - w) * 3;
-  data = malloc(w * h * 3);
+  data = _gdk_malloc_image(w, h);
   if (data == NULL)
     return;
   ptr1 = im->rgb_data + (y * w3) + (x * 3);
@@ -571,7 +571,7 @@ gdk_imlib_crop_and_clone_image(GdkImlibImage * im, int x, int y, int w, int h)
 
   w3 = im->rgb_width * 3;
   w4 = (im->rgb_width - w) * 3;
-  data = malloc(w * h * 3);
+  data = _gdk_malloc_image(w, h);
   if (data == NULL)
     return NULL;
   ptr1 = im->rgb_data + (y * w3) + (x * 3);
@@ -838,7 +838,7 @@ gdk_imlib_rotate_image(GdkImlibImage * im, gint d)
   w3 = im->rgb_width * 3;
   w4 = im->rgb_height * 3;
 
-  data = malloc(im->rgb_width * im->rgb_height * 3);
+  data = _gdk_malloc_image(im->rgb_width, im->rgb_height);
   if (data == NULL)
     return;
 
@@ -887,7 +887,7 @@ gdk_imlib_create_image_from_data(unsigned char *data, unsigned char *alpha, gint
   im->map = NULL;
   im->rgb_width = w;
   im->rgb_height = h;
-  im->rgb_data = malloc(im->rgb_width * im->rgb_height * 3);
+  im->rgb_data = _gdk_malloc_image(im->rgb_width, im->rgb_height);
   if (!im->rgb_data)
     {
       free(im);
@@ -948,7 +948,7 @@ gdk_imlib_clone_image(GdkImlibImage * im)
   im2->map = NULL;
   im2->rgb_width = im->rgb_width;
   im2->rgb_height = im->rgb_height;
-  im2->rgb_data = malloc(im2->rgb_width * im2->rgb_height * 3);
+  im2->rgb_data = _gdk_malloc_image(im2->rgb_width, im2->rgb_height);
   if (!im2->rgb_data)
     {
       free(im2);
@@ -1028,7 +1028,7 @@ gdk_imlib_clone_scaled_image(GdkImlibImage * im, int w, int h)
   im2->map = NULL;
   im2->rgb_width = w;
   im2->rgb_height = h;
-  im2->rgb_data = malloc(w * h * 3);
+  im2->rgb_data = _gdk_malloc_image(w, h);
   if (!im2->rgb_data)
     {
       free(im2);
@@ -1277,7 +1277,7 @@ gdk_imlib_create_image_from_xpm_data(char **data)
 	    }
 	  im->rgb_width = w;
 	  im->rgb_height = h;
-	  im->rgb_data = malloc(im->rgb_width * im->rgb_height * 3);
+	  im->rgb_data = _gdk_malloc_image(im->rgb_width, im->rgb_height);
 	  if (!im->rgb_data)
 	    {
 	      free(cmap);
@@ -1658,7 +1658,7 @@ _gdk_imlib_open_helper(const char *instring, const char *fn, const char *mode)
       /*
        *    Generate a quanting pipeline
        */
-      fprintf(stderr, "Not currently supported: install ImageMagic.\n");
+      fprintf(stderr, "Not currently supported: install ImageMagick.\n");
       return NULL;
     }
   /*
@@ -2092,7 +2092,7 @@ gdk_imlib_create_image_from_drawable(GdkWindow * gwin, GdkBitmap * gmask,
 	  ctab[i].pixel = cols[i].pixel;
 	}
     }
-  data = malloc(width * height * 3);
+  data = _gdk_malloc_image(width, height);
   if (data)
     {
       ptr = data;
